@@ -2,4 +2,6 @@ mod adjust_ensure;
 mod adjust_validate;
 mod ensure;
 mod non_clone;
+#[cfg(feature = "serde")]
+mod serde_integration;
 mod validate;
